.. _tutorials-tweets:

==================================
Twitter Streaming
==================================

The code for this example is located in the :mod:`examples.tweets.manage`
module.

.. automodule:: examples.tweets.manage
